@@ -1,4 +1,3 @@
-original_envvar <- Sys.getenv("RTOOT_DEFAULT_TOKEN")
 original_option <- options("rtoot_token")$rtoot_token
 options("rtoot_cheatcode" = NULL)
 
@@ -30,6 +29,9 @@ envvar_string <- strsplit(
 
 test_that("seven conditions", {
   skip_if(!file.exists(saved_token_path))
+  original_envvar <- Sys.getenv("RTOOT_DEFAULT_TOKEN")
+  withr::defer(Sys.setenv(RTOOT_DEFAULT_TOKEN = original_envvar))
+
   ## don't test the all FALSE condition; see below
   condition <- tibble::tibble(expand.grid(
     token = c(TRUE, FALSE),
@@ -83,51 +85,51 @@ test_that("cheatmode", {
 
 test_that("cheatmode, invalid_token", {
   skip_on_cran()
-  options("rtoot_cheatcode" = "uuddlrlrba")
-  options("rtoot_cheat_answer" = 2)
+  withr::local_options(rtoot_cheatcode = "uuddlrlrba", rtoot_cheat_answer = 2)
+
   expect_error(x <- check_token_rtoot(token = iris, verbose = FALSE))
   output <- capture_message(check_token_rtoot(token = iris, verbose = TRUE))
   expect_true(grepl(
     "Your token is invalid. Do you want to authenticate now?",
     output
   ))
-  options("rtoot_cheatcode" = NULL)
-  options("rtoot_cheat_answer" = NULL)
 })
 
 test_that("cheatmode, file doesn't exist", {
   skip_on_cran()
-  options("rtoot_cheatcode" = "uuddlrlrba")
-  options("rtoot_cheat_answer" = 2)
-  random_path <- tempfile(fileext = gen_random_token())
+  withr::local_options(
+    rtoot_cheatcode = "uuddlrlrba",
+    rtoot_cheat_answer = 2,
+    rtoot_token = tempfile(fileext = gen_random_token())
+  )
+  withr::local_envvar(RTOOT_DEFAULT_TOKEN = "")
+
+  random_path <- options("rtoot_token")$rtoot_token
   expect_false(file.exists(random_path))
-  options("rtoot_token" = random_path)
-  Sys.setenv(RTOOT_DEFAULT_TOKEN = "")
   expect_error(x <- check_token_rtoot(verbose = FALSE))
   output <- capture_message(check_token_rtoot(verbose = TRUE))
   expect_true(grepl(
     "This seems to be the first time you are using rtoot. Do you want to authenticate now?",
     output
   ))
-  options("rtoot_cheatcode" = NULL)
-  options("rtoot_cheat_answer" = NULL)
 })
 
 test_that("cheatmode, nothing in ~/.config/R/rtoot/", {
   skip_on_cran()
   skip_if(length(list.files(tools::R_user_dir("rtoot", "config"))) != 0)
-  options("rtoot_cheatcode" = "uuddlrlrba")
-  options("rtoot_cheat_answer" = 2)
-  options("rtoot_token" = NULL)
-  Sys.setenv(RTOOT_DEFAULT_TOKEN = "")
+  withr::local_options(
+    rtoot_cheatcode = "uuddlrlrba",
+    rtoot_cheat_answer = 2,
+    rtoot_token = NULL
+  )
+  withr::local_envvar(RTOOT_DEFAULT_TOKEN = "")
+
   expect_error(x <- check_token_rtoot(verbose = FALSE))
   output <- capture_message(check_token_rtoot())
   expect_true(grepl(
     "This seems to be the first time you are using rtoot. Do you want to authenticate now?",
     output
   ))
-  options("rtoot_cheatcode" = NULL)
-  options("rtoot_cheat_answer" = NULL)
 })
 
 test_that("A valid token in ~/.config/R/rtoot/", {
@@ -135,8 +137,8 @@ test_that("A valid token in ~/.config/R/rtoot/", {
   skip_if(length(list.files(tools::R_user_dir("rtoot", "config"))) != 0)
   ## skip if that's not writable
   skip_if(file.access(tools::R_user_dir("rtoot", "config"), mode = 2) != 0)
-  options("rtoot_token" = NULL)
-  Sys.setenv(RTOOT_DEFAULT_TOKEN = "")
+  withr::local_options(rtoot_token = NULL)
+  withr::local_envvar(RTOOT_DEFAULT_TOKEN = "")
   saved_token2 <- list(bearer = gen_random_token())
   saved_token2$type <- "user"
   saved_token2$instance <- "saved_token"
@@ -176,7 +178,6 @@ test_that("A valid token in ~/.config/R/rtoot/", {
 
 ## tear down
 
-Sys.setenv(RTOOT_DEFAULT_TOKEN = original_envvar)
 options("rtoot_token" = original_option)
 unlink(saved_token_path)
 options("rtoot_cheatcode" = NULL)
